import React from "react"
import { graphql, PageProps } from "gatsby"
import { twMerge } from "tailwind-merge"
import {
    Layout,
    Content,
    Sections,
    SideBar,
} from "@onegeo-suite/gatsby-theme-onegeo"

import { PageContext } from "../context/page"

interface ISection {
    sections_id: string[] | []
}
interface IPageContext {
    directus: {
        pages: {
            id: string
            title: string
            content: string
            slug: string
            sections: ISection[] | []
            toc: boolean
            options?: any
        }
    }
}
// [&_h1]:scroll-mt-28  [&_h2]:scroll-mt-28  [&_h3]:scroll-mt-28  [&_h4]:scroll-mt-28 text-secondary-content
const PageTemplate = ({ data }: PageProps<IPageContext>) => {
    const news = data.directus.pages[0]
    const { title, content, sections, toc = false, documents, links } = news

    const idsSections = sections.map((section: any) => section.sections_id.id)

    const options = news.options ?? {}
    const oClass = options.class || {}
    const oContext = options.context || {}

    let position = "right"

    return (
        <PageContext.Provider value={oContext}>
            <Layout theme={options.theme}>
                <Content
                    className={twMerge(
                        "flex max-w-6xl flex-wrap gap-6 lg:mt-8 lg:flex-nowrap",
                        oClass.main
                    )}
                >
                    {/* Todo Fix mobile mode */}
                    {position === "left" ? (
                        <SideBar
                            documents={documents}
                            links={links}
                            toc={toc}
                        />
                    ) : null}
                    <div
                        className={twMerge(
                            "bg-base-100 w-full rounded-xl p-6 lg:shadow-lg",
                            oClass.body
                        )}
                    >
                        {content && (
                            <div
                                className={twMerge(
                                    "prose lg:prose-lg prose-headings:scroll-mt-24 max-w-4xl",
                                    oClass.content
                                )}
                                dangerouslySetInnerHTML={{ __html: content }}
                            ></div>
                        )}

                        {Object.keys(idsSections).length !== 0 && (
                            <Sections ids={idsSections} />
                        )}
                    </div>
                    {position === "right" ? (
                        <SideBar
                            documents={documents}
                            links={links}
                            toc={toc}
                        />
                    ) : null}
                </Content>
            </Layout>
        </PageContext.Provider>
    )
}

export default PageTemplate

export const query = graphql`
    query ($id: DirectusData_GraphQLStringOrFloat!) {
        directus {
            pages(filter: { id: { _eq: $id } }) {
                sections {
                    sections_id {
                        id
                    }
                }
                content
                id
                title
                slug
                toc
                options
                links {
                    id
                    links_id {
                        url
                    }
                }
                documents {
                    directus_files_id {
                        id
                        filename_download
                        imageFile {
                            publicURL
                        }
                    }
                }
            }
        }
    }
`
